==> zope-zms_2.9.2-a29.orig.tar.gz: zms/_mimetypes.py <==
###################################################################################################
# _mimetypes.py
#
# $Id: _mimetypes.py,v 1.2 2003/10/25 14:16:18 dnordmann Exp $
# $Name:  $
# $Author: dnordmann $
# $Revision: 1.2 $
#
# Implementation of class _mimetype.MimeType (see below).
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################


""" Globals. """

application_msaccess = "mime_type.application_msaccess.gif"
application_mspowerpoint = "mime_type.application_mspowerpoint.gif"
application_msword = "mime_type.application_msword.gif"
application_octet_stream = "mime_type.application_octet_stream.gif"
application_pdf = "mime_type.application_pdf.gif"
application_rtf = "mime_type.application_rtf.gif"
application_sh = "mime_type.application_sh.gif"
application_shockwave_flash = "mime_type.application_shockwave_flash.gif"
application_x_director = "mime_type.application_x_director.gif"
application_x_excel = "mime_type.application_x_excel.gif"
application_x_x509_ca_cert = "mime_type.application_x_x509_ca_cert.gif"
application_visio = "mime_type.application_visio.gif"
application_zip = "mime_type.application_zip.gif"
audio_basic = "mime_type.audio_basic.gif"
audio_midi = "mime_type.audio_midi.gif"
content_unknown = "zmsfile.gif"
image_basic = "mime_type.image_basic.gif"
image_bmp = "mime_type.image_bmp.gif"
image_gif = "mime_type.image_gif.gif"
image_jpeg = "mime_type.image_jpeg.gif"
image_tiff = "mime_type.image_tiff.gif"
text_html = "mime_type.text_html.gif"
text_plain = "mime_type.text_plain.gif"
text_xml = "mime_type.text_xml.gif"
text_xsd = "mime_type.text_xsd.gif"
text_xsl = "mime_type.text_xsl.gif"
video_basic = "mime_type.video_basic.gif"

dctMimeType = {
	'animation/narrative':content_unknown
	,'application/activemessage':content_unknown
	,'application/andrew-inset':content_unknown
	,'application/applefile':content_unknown
	,'application/atomicmail':content_unknown
	,'application/dca-rft':content_unknown
	,'application/dec-dx':content_unknown
	,'application/dsptype':content_unknown
	,'application/fastman':content_unknown
	,'application/font-tdpfr':content_unknown
	,'application/futuresplash':content_unknown
	,'application/mac-binhex40':content_unknown
	,'application/mac-compactpro':content_unknown
	,'application/macwriteii':content_unknown
	,'application/mspowerpoint':application_mspowerpoint
	,'application/vnd.ms-powerpoint':application_mspowerpoint
	,'application/vnd.ms-access':application_msaccess
	,'application/msword':application_msword
	,'application/news-message-id':content_unknown
	,'application/news-transmission':content_unknown
	,'application/octet-stream':application_octet_stream
	,'application/oda':content_unknown
	,'application/pdf':application_pdf
	,'application/postscript':content_unknown
	,'application/remote-printing':content_unknown
	,'application/rtf':application_rtf
	,'application/slate':content_unknown
	,'application/softvision':content_unknown
	,'application/wita':content_unknown
	,'application/wordperfect5.1':content_unknown
	,'application/x-authorware-bin':content_unknown
	,'application/x-authorware-map':content_unknown
	,'application/x-authorware-seg':content_unknown
	,'application/x-bcpio':content_unknown
	,'application/x-bzip2':content_unknown
	,'application/x-calquick':content_unknown
	,'application/x-cdlink':content_unknown
	,'application/x-cocoa':content_unknown
	,'application/x-compress':content_unknown
	,'application/x-cpio':content_unknown
	,'application/x-csh':content_unknown
	,'application/x-director':application_x_director
	,'application/x-dvi':content_unknown
	,'application/x-excel':application_x_excel
	,'application/vnd.ms-excel':application_x_excel
	,'application/x-expandedbook':content_unknown
	,'application/x-gtar':application_zip
	,'application/x-gzip':application_zip
	,'application/x-hdf':content_unknown
	,'application/x-httpd-cgi':content_unknown
	,'application/x-javascript':content_unknown
	,'application/x-koan':content_unknown
	,'application/x-latex':content_unknown
	,'application/x-lzh':content_unknown
	,'application/x-mapserver':content_unknown
	,'application/x-mascot':content_unknown
	,'application/x-mif':content_unknown
	,'application/x-netcdf':content_unknown
	,'application/x-ns-proxy-auto-config':content_unknown
	,'application/x-pixelscooter':content_unknown
	,'application/x-pointplus':content_unknown
	,'application/x-sh':application_sh
	,'application/x-shar':content_unknown
	,'application/x-shockwave-flash':application_shockwave_flash
	,'application/x-sprite':content_unknown
	,'application/x-spt':content_unknown
	,'application/x-stuffit':content_unknown
	,'application/x-sv4cpio':content_unknown
	,'application/x-sv4crc':content_unknown
	,'application/x-tar':application_zip
	,'application/x-tcl':content_unknown
	,'application/x-tex':content_unknown
	,'application/x-texinfo':content_unknown
	,'application/x-troff':content_unknown
	,'application/x-troff-man':content_unknown
	,'application/x-troff-me':content_unknown
	,'application/x-troff-ms':content_unknown
	,'application/x-ustar':content_unknown
	,'application/x-unknown-content-type-Visio.Drawing.4':application_visio
	,'application/x-wais-source':content_unknown
	,'application/x-xdma':content_unknown
	,'application/x-x509-ca-cert':application_x_x509_ca_cert
	,'application/x-zip-compressed':application_zip
	,'application/zip':application_zip
	,'audio/basic':audio_basic
	,'audio/echospeech':audio_basic
	,'audio/midi':audio_midi
	,'audio/mpeg':audio_basic
	,'audio/tsplayer':audio_basic
	,'audio/voxware':audio_basic
	,'audio/x-aiff':audio_basic
	,'audio/x-bamba':audio_basic
	,'audio/x-chacha':audio_basic
	,'audio/x-mio':audio_basic
	,'audio/x-pn-realaudio':audio_basic
	,'audio/x-pn-realaudio-plugin':audio_basic
	,'audio/x-twinvq':audio_basic
	,'audio/x-twinvq-plugin':audio_basic
	,'audio/x-wav':audio_basic
	,'content/unknown':content_unknown
	,'chemical/x-csml':content_unknown
	,'chemical/x-embl-dl-nucleotide':content_unknown
	,'chemical/x-gaussian-input':content_unknown
	,'chemical/x-mdl-molfile':content_unknown
	,'chemical/x-mopac-input':content_unknown
	,'chemical/x-pdb':content_unknown
	,'chemical/x-xyz':content_unknown
	,'i-world/i-vrml':content_unknown
	,'image/bmp':image_bmp
	,'image/fif':image_basic
	,'image/gif':image_gif
	,'image/ief':image_basic
	,'image/jpeg':image_jpeg
	,'image/pjpeg':image_jpeg
	,'image/png':image_basic
	,'image/tiff':image_tiff
	,'image/vasa':image_basic
	,'image/x-cmu-raster':image_basic
	,'image/x-freehand':image_basic
	,'image/x-jps':image_basic
	,'image/x-portable-anymap':image_basic
	,'image/x-portable-bitmap':image_basic
	,'image/x-portable-graymap':image_basic
	,'image/x-portable-pixmap':image_basic
	,'image/x-rgb':image_basic
	,'image/x-xbitmap':image_basic
	,'image/x-xpixmap':image_basic
	,'image/x-xres':image_basic
	,'image/x-xwindowdump':image_basic
	,'message/external-body':content_unknown
	,'message/news':content_unknown
	,'message/partial':content_unknown
	,'message/rfc822':content_unknown
	,'multipart/alternative':content_unknown
	,'multipart/appledouble':content_unknown
	,'multipart/digest':content_unknown
	,'multipart/mixed':content_unknown
	,'multipart/parallel':content_unknown
	,'plugin/listenup':content_unknown
	,'plugin/wanimate':content_unknown
	,'text/html':text_html
	,'text/plain':text_plain
	,'text/richtext':application_rtf
	,'text/tab-separated-values':text_plain
	,'text/xml':text_xml
	,'text/xsd':text_xsd
	,'text/xsl':text_xsl
	,'text/x-setext':text_plain
	,'text/x-sgml':text_plain
	,'text/x-speech':text_plain
	,'text/x-vcard':text_plain
	,'video/mpeg':video_basic
	,'video/quicktime':video_basic
	,'video/vnd.vivo':video_basic
	,'video/x-bamba':video_basic
	,'video/x-msvideo':video_basic
	,'video/x-sgi-movie':video_basic
	,'video/x-tango':video_basic
	,'video/x-vif':video_basic
	,'workbook/formulaone':content_unknown
	,'world/x-panoramix':content_unknown
	,'x-conference/x-cooltalk':content_unknown
	,'x-world/x-d96':content_unknown
	,'x-world/x-svr':content_unknown
	,'x-world/x-vrml':content_unknown
	,'x-world/x-vrt':content_unknown
	}

###################################################################################################

==> zope-zms_2.10.1-33.orig.tar.gz: zms/_mimetypes.py <==
###################################################################################################
# _mimetypes.py
#
# $Id: _mimetypes.py,v 1.2 2003/10/25 14:16:18 zmsdev Exp $
# $Name:  $
# $Author: zmsdev $
# $Revision: 1.2 $
#
# Implementation of class _mimetype.MimeType (see below).
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################


""" Globals. """

application_msaccess = "mime_type.application_msaccess.gif"
application_mspowerpoint = "mime_type.application_mspowerpoint.gif"
application_msword = "mime_type.application_msword.gif"
application_octet_stream = "mime_type.application_octet_stream.gif"
application_pdf = "mime_type.application_pdf.gif"
application_rtf = "mime_type.application_rtf.gif"
application_sh = "mime_type.application_sh.gif"
application_shockwave_flash = "mime_type.application_shockwave_flash.gif"
application_x_director = "mime_type.application_x_director.gif"
application_x_excel = "mime_type.application_x_excel.gif"
application_x_x509_ca_cert = "mime_type.application_x_x509_ca_cert.gif"
application_visio = "mime_type.application_visio.gif"
application_zip = "mime_type.application_zip.gif"
audio_basic = "mime_type.audio_basic.gif"
audio_midi = "mime_type.audio_midi.gif"
content_unknown = "zmsfile.gif"
image_basic = "mime_type.image_basic.gif"
image_bmp = "mime_type.image_bmp.gif"
image_gif = "mime_type.image_gif.gif"
image_jpeg = "mime_type.image_jpeg.gif"
image_tiff = "mime_type.image_tiff.gif"
text_html = "mime_type.text_html.gif"
text_plain = "mime_type.text_plain.gif"
text_xml = "mime_type.text_xml.gif"
text_xsd = "mime_type.text_xsd.gif"
text_xsl = "mime_type.text_xsl.gif"
video_basic = "mime_type.video_basic.gif"

dctMimeType = {
	 'application/mspowerpoint':application_mspowerpoint
	,'application/vnd.ms-access':application_msaccess
	,'application/vnd.ms-excel':application_x_excel
	,'application/vnd.ms-powerpoint':application_mspowerpoint
	,'application/msword':application_msword
	,'application/octet-stream':application_octet_stream
	,'application/pdf':application_pdf
	,'application/rtf':application_rtf
	,'application/vnd.visio':application_visio
	,'application/x-director':application_x_director
	,'application/x-excel':application_x_excel
	,'application/x-gtar':application_zip
	,'application/x-gzip':application_zip
	,'application/x-sh':application_sh
	,'application/x-shockwave-flash':application_shockwave_flash
	,'application/x-tar':application_zip
	,'application/x-unknown-content-type-Visio.Drawing.4':application_visio
	,'application/x-x509-ca-cert':application_x_x509_ca_cert
	,'application/x-zip-compressed':application_zip
	,'application/zip':application_zip
	,'audio/basic':audio_basic
	,'audio/echospeech':audio_basic
	,'audio/midi':audio_midi
	,'audio/mpeg':audio_basic
	,'audio/tsplayer':audio_basic
	,'audio/voxware':audio_basic
	,'audio/x-aiff':audio_basic
	,'audio/x-bamba':audio_basic
	,'audio/x-chacha':audio_basic
	,'audio/x-mio':audio_basic
	,'audio/x-pn-realaudio':audio_basic
	,'audio/x-pn-realaudio-plugin':audio_basic
	,'audio/x-twinvq':audio_basic
	,'audio/x-twinvq-plugin':audio_basic
	,'audio/x-wav':audio_basic
	,'image/bmp':image_bmp
	,'image/fif':image_basic
	,'image/gif':image_gif
	,'image/ief':image_basic
	,'image/jpeg':image_jpeg
	,'image/pjpeg':image_jpeg
	,'image/png':image_basic
	,'image/tiff':image_tiff
	,'image/vasa':image_basic
	,'image/x-cmu-raster':image_basic
	,'image/x-freehand':image_basic
	,'image/x-jps':image_basic
	,'image/x-portable-anymap':image_basic
	,'image/x-portable-bitmap':image_basic
	,'image/x-portable-graymap':image_basic
	,'image/x-portable-pixmap':image_basic
	,'image/x-rgb':image_basic
	,'image/x-xbitmap':image_basic
	,'image/x-xpixmap':image_basic
	,'image/x-xres':image_basic
	,'image/x-xwindowdump':image_basic
	,'text/html':text_html
	,'text/plain':text_plain
	,'text/richtext':application_rtf
	,'text/tab-separated-values':text_plain
	,'text/xml':text_xml
	,'text/xsd':text_xsd
	,'text/xsl':text_xsl
	,'text/x-setext':text_plain
	,'text/x-sgml':text_plain
	,'text/x-speech':text_plain
	,'text/x-vcard':text_plain
	,'video/mpeg':video_basic
	,'video/quicktime':video_basic
	,'video/vnd.vivo':video_basic
	,'video/x-bamba':video_basic
	,'video/x-msvideo':video_basic
	,'video/x-sgi-movie':video_basic
	,'video/x-tango':video_basic
	,'video/x-vif':video_basic
	}

###################################################################################################
